==> dpws-model-1.1.0-sources.jar: org/somda/sdc/dpws/soap/wsdiscovery/model/SigType.java <==

package org.somda.sdc.dpws.soap.wsdiscovery.model;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlIDREF;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.w3c.dom.Element;


/**
 * <p>Java class for SigType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SigType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;any processContents='lax' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="Scheme" use="required" type="{http://www.w3.org/2001/XMLSchema}anyURI" /&gt;
 *       &lt;attribute name="KeyId" type="{http://www.w3.org/2001/XMLSchema}base64Binary" /&gt;
 *       &lt;attribute name="Refs" use="required" type="{http://www.w3.org/2001/XMLSchema}IDREFS" /&gt;
 *       &lt;attribute name="Sig" use="required" type="{http://www.w3.org/2001/XMLSchema}base64Binary" /&gt;
 *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SigType", namespace = "http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01", propOrder = {
    "any"
})
public class SigType implements ToString2
{

    @XmlAnyElement(lax = true)
    protected List<Object> any;
    @XmlAttribute(name = "Scheme", required = true)
    @XmlSchemaType(name = "anyURI")
    protected String scheme;
    @XmlAttribute(name = "KeyId")
    protected byte[] keyId;
    @XmlAttribute(name = "Refs", required = true)
    @XmlIDREF
    @XmlSchemaType(name = "IDREFS")
    protected List<Object> refs;
    @XmlAttribute(name = "Sig", required = true)
    protected byte[] sig;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the any property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the any property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAny().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Element }
     * {@link Object }
     * 
     * 
     */
    public List<Object> getAny() {
        if (any == null) {
            any = new ArrayList<Object>();
        }
        return this.any;
    }

    /**
     * Ruft den Wert der scheme-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getScheme() {
        return scheme;
    }

    /**
     * Legt den Wert der scheme-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setScheme(String value) {
        this.scheme = value;
    }

    /**
     * Ruft den Wert der keyId-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getKeyId() {
        return keyId;
    }

    /**
     * Legt den Wert der keyId-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setKeyId(byte[] value) {
        this.keyId = value;
    }

    /**
     * Gets the value of the refs property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the refs property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getRefs().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Object }
     * 
     * 
     */
    public List<Object> getRefs() {
        if (refs == null) {
            refs = new ArrayList<Object>();
        }
        return this.refs;
    }

    /**
     * Ruft den Wert der sig-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getSig() {
        return sig;
    }

    /**
     * Legt den Wert der sig-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setSig(byte[] value) {
        this.sig = value;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setAny(List<Object> value) {
        this.any = null;
        if (value!= null) {
            List<Object> draftl = this.getAny();
            draftl.addAll(value);
        }
    }

    public void setRefs(List<Object> value) {
        this.refs = null;
        if (value!= null) {
            List<Object> draftl = this.getRefs();
            draftl.addAll(value);
        }
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final SigType that = ((SigType) object);
        {
            List<Object> leftAny;
            leftAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            List<Object> rightAny;
            rightAny = (((that.any!= null)&&(!that.any.isEmpty()))?that.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    return false;
                }
            }
        }
        {
            String leftScheme;
            leftScheme = this.getScheme();
            String rightScheme;
            rightScheme = that.getScheme();
            if (this.scheme!= null) {
                if (that.scheme!= null) {
                    if (!leftScheme.equals(rightScheme)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.scheme!= null) {
                    return false;
                }
            }
        }
        {
            byte[] leftKeyId;
            leftKeyId = this.getKeyId();
            byte[] rightKeyId;
            rightKeyId = that.getKeyId();
            if (this.keyId!= null) {
                if (that.keyId!= null) {
                    if (!Arrays.equals(leftKeyId, rightKeyId)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.keyId!= null) {
                    return false;
                }
            }
        }
        {
            List<Object> leftRefs;
            leftRefs = (((this.refs!= null)&&(!this.refs.isEmpty()))?this.getRefs():null);
            List<Object> rightRefs;
            rightRefs = (((that.refs!= null)&&(!that.refs.isEmpty()))?that.getRefs():null);
            if ((this.refs!= null)&&(!this.refs.isEmpty())) {
                if ((that.refs!= null)&&(!that.refs.isEmpty())) {
                    if (!leftRefs.equals(rightRefs)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.refs!= null)&&(!that.refs.isEmpty())) {
                    return false;
                }
            }
        }
        {
            byte[] leftSig;
            leftSig = this.getSig();
            byte[] rightSig;
            rightSig = that.getSig();
            if (this.sig!= null) {
                if (that.sig!= null) {
                    if (!Arrays.equals(leftSig, rightSig)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.sig!= null) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                currentHashCode += theAny.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theScheme;
            theScheme = this.getScheme();
            if (this.scheme!= null) {
                currentHashCode += theScheme.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            byte[] theKeyId;
            theKeyId = this.getKeyId();
            currentHashCode += Arrays.hashCode(theKeyId);
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<Object> theRefs;
            theRefs = (((this.refs!= null)&&(!this.refs.isEmpty()))?this.getRefs():null);
            if ((this.refs!= null)&&(!this.refs.isEmpty())) {
                currentHashCode += theRefs.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            byte[] theSig;
            theSig = this.getSig();
            currentHashCode += Arrays.hashCode(theSig);
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
        }
        {
            String theScheme;
            theScheme = this.getScheme();
            strategy.appendField(locator, this, "scheme", buffer, theScheme, (this.scheme!= null));
        }
        {
            byte[] theKeyId;
            theKeyId = this.getKeyId();
            strategy.appendField(locator, this, "keyId", buffer, theKeyId, (this.keyId!= null));
        }
        {
            List<Object> theRefs;
            theRefs = (((this.refs!= null)&&(!this.refs.isEmpty()))?this.getRefs():null);
            strategy.appendField(locator, this, "refs", buffer, theRefs, ((this.refs!= null)&&(!this.refs.isEmpty())));
        }
        {
            byte[] theSig;
            theSig = this.getSig();
            strategy.appendField(locator, this, "sig", buffer, theSig, (this.sig!= null));
        }
        return buffer;
    }

}

==> dpws-model-2.0.0-sources.jar: org/somda/sdc/dpws/soap/wsdiscovery/model/SigType.java <==

package org.somda.sdc.dpws.soap.wsdiscovery.model;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlIDREF;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.w3c.dom.Element;


/**
 * <p>Java class for SigType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SigType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;any processContents='lax' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="Scheme" use="required" type="{http://www.w3.org/2001/XMLSchema}anyURI" /&gt;
 *       &lt;attribute name="KeyId" type="{http://www.w3.org/2001/XMLSchema}base64Binary" /&gt;
 *       &lt;attribute name="Refs" use="required" type="{http://www.w3.org/2001/XMLSchema}IDREFS" /&gt;
 *       &lt;attribute name="Sig" use="required" type="{http://www.w3.org/2001/XMLSchema}base64Binary" /&gt;
 *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SigType", namespace = "http://docs.oasis-open.org/ws-dd/ns/discovery/2009/01", propOrder = {
    "any"
})
public class SigType implements ToString2
{

    @XmlAnyElement(lax = true)
    protected List<Object> any;
    @XmlAttribute(name = "Scheme", required = true)
    @XmlSchemaType(name = "anyURI")
    protected String scheme;
    @XmlAttribute(name = "KeyId")
    protected byte[] keyId;
    @XmlAttribute(name = "Refs", required = true)
    @XmlIDREF
    @XmlSchemaType(name = "IDREFS")
    protected List<Object> refs;
    @XmlAttribute(name = "Sig", required = true)
    protected byte[] sig;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the any property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the any property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAny().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Element }
     * {@link Object }
     * 
     * 
     */
    public List<Object> getAny() {
        if (any == null) {
            any = new ArrayList<Object>();
        }
        return this.any;
    }

    /**
     * Gets the value of the scheme property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getScheme() {
        return scheme;
    }

    /**
     * Sets the value of the scheme property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setScheme(String value) {
        this.scheme = value;
    }

    /**
     * Gets the value of the keyId property.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getKeyId() {
        return keyId;
    }

    /**
     * Sets the value of the keyId property.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setKeyId(byte[] value) {
        this.keyId = value;
    }

    /**
     * Gets the value of the refs property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the refs property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getRefs().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Object }
     * 
     * 
     */
    public List<Object> getRefs() {
        if (refs == null) {
            refs = new ArrayList<Object>();
        }
        return this.refs;
    }

    /**
     * Gets the value of the sig property.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getSig() {
        return sig;
    }

    /**
     * Sets the value of the sig property.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setSig(byte[] value) {
        this.sig = value;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setAny(List<Object> value) {
        this.any = null;
        if (value!= null) {
            List<Object> draftl = this.getAny();
            draftl.addAll(value);
        }
    }

    public void setRefs(List<Object> value) {
        this.refs = null;
        if (value!= null) {
            List<Object> draftl = this.getRefs();
            draftl.addAll(value);
        }
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final SigType that = ((SigType) object);
        {
            List<Object> leftAny;
            leftAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            List<Object> rightAny;
            rightAny = (((that.any!= null)&&(!that.any.isEmpty()))?that.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    return false;
                }
            }
        }
        {
            String leftScheme;
            leftScheme = this.getScheme();
            String rightScheme;
            rightScheme = that.getScheme();
            if (this.scheme!= null) {
                if (that.scheme!= null) {
                    if (!leftScheme.equals(rightScheme)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.scheme!= null) {
                    return false;
                }
            }
        }
        {
            byte[] leftKeyId;
            leftKeyId = this.getKeyId();
            byte[] rightKeyId;
            rightKeyId = that.getKeyId();
            if (this.keyId!= null) {
                if (that.keyId!= null) {
                    if (!Arrays.equals(leftKeyId, rightKeyId)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.keyId!= null) {
                    return false;
                }
            }
        }
        {
            List<Object> leftRefs;
            leftRefs = (((this.refs!= null)&&(!this.refs.isEmpty()))?this.getRefs():null);
            List<Object> rightRefs;
            rightRefs = (((that.refs!= null)&&(!that.refs.isEmpty()))?that.getRefs():null);
            if ((this.refs!= null)&&(!this.refs.isEmpty())) {
                if ((that.refs!= null)&&(!that.refs.isEmpty())) {
                    if (!leftRefs.equals(rightRefs)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.refs!= null)&&(!that.refs.isEmpty())) {
                    return false;
                }
            }
        }
        {
            byte[] leftSig;
            leftSig = this.getSig();
            byte[] rightSig;
            rightSig = that.getSig();
            if (this.sig!= null) {
                if (that.sig!= null) {
                    if (!Arrays.equals(leftSig, rightSig)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.sig!= null) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                currentHashCode += theAny.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theScheme;
            theScheme = this.getScheme();
            if (this.scheme!= null) {
                currentHashCode += theScheme.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            byte[] theKeyId;
            theKeyId = this.getKeyId();
            currentHashCode += Arrays.hashCode(theKeyId);
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<Object> theRefs;
            theRefs = (((this.refs!= null)&&(!this.refs.isEmpty()))?this.getRefs():null);
            if ((this.refs!= null)&&(!this.refs.isEmpty())) {
                currentHashCode += theRefs.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            byte[] theSig;
            theSig = this.getSig();
            currentHashCode += Arrays.hashCode(theSig);
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
        }
        {
            String theScheme;
            theScheme = this.getScheme();
            strategy.appendField(locator, this, "scheme", buffer, theScheme, (this.scheme!= null));
        }
        {
            byte[] theKeyId;
            theKeyId = this.getKeyId();
            strategy.appendField(locator, this, "keyId", buffer, theKeyId, (this.keyId!= null));
        }
        {
            List<Object> theRefs;
            theRefs = (((this.refs!= null)&&(!this.refs.isEmpty()))?this.getRefs():null);
            strategy.appendField(locator, this, "refs", buffer, theRefs, ((this.refs!= null)&&(!this.refs.isEmpty())));
        }
        {
            byte[] theSig;
            theSig = this.getSig();
            strategy.appendField(locator, this, "sig", buffer, theSig, (this.sig!= null));
        }
        return buffer;
    }

}
